# ssi-views
A simple Django application to process SSI includes

[![PyPI](https://img.shields.io/pypi/v/ssi-views.svg)](https://pypi.org/project/ssi-views/)
[![Build Status](https://travis-ci.org/dldevinc/ssi-views.svg?branch=master)](https://travis-ci.org/dldevinc/ssi-views)

## Development and Testing
After cloning the Git repository, you should install this
in a virtualenv and set up for development:
```shell script
virtualenv .venv
source .venv/bin/activate
pip install -r ./requirements_dev.txt
pre-commit install
```
